@@ -1,13 +1,14 @@
-#' flightsbr: Download Flight And Airport Data from Brazil
+#' flightsbr: Download Flight and Airport Data from Brazil
 #'
 #' Download flight and airport data from Brazil’s Civil Aviation Agency (ANAC)
 #'  <https://www.gov.br/anac>. The data includes detailed information on all
-#'  aircrafts, aerodromes, airports, and airports movements registered in ANAC,
+#'  aircrafts, aerodromes, airports, and airport movements registered in ANAC,
 #'   and on every international flight to and from Brazil, as well as domestic
 #'   flights within the country.
 #'
 #' @section Usage:
-#' Please check the vignettes on the [website](https://ipeagit.github.io/flightsbr/).
+#' Please check the vignettes and data documentation on the
+#' [website](https://ipeagit.github.io/flightsbr/).
 #'
 #' @docType package
 #' @name flightsbr
@@ -20,5 +21,7 @@
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 utils::globalVariables( c('month',
-                          'year') )
+                          'year',
+                          'latitude',
+                          'longitude') )
 
