@@ -10,7 +10,7 @@
 get_flight_dates_available <- function() {
 
   # read html table
-  url = 'https://www.gov.br/anac/pt-br/assuntos/regulados/empresas-aereas/Instrucoes-para-a-elaboracao-e-apresentacao-das-demonstracoes-contabeis/microdados/'
+  url = 'https://www.gov.br/anac/pt-br/assuntos/regulados/empresas-aereas/Instrucoes-para-a-elaboracao-e-apresentacao-das-demonstracoes-contabeis/envio-de-informacoes'
   h <- try(rvest::read_html(url), silent = TRUE)
 
   # check if internet connection worked
@@ -284,18 +284,18 @@ generate_all_months <- function(date) { # nocov start
 get_flights_url <- function(type, year, month) { # nocov start
 
   # old https://www.gov.br/anac/pt-br/assuntos/regulados/empresas-aereas/envio-de-informacoes/microdados/basica2021-01.zip
+  # old https://www.gov.br/anac/pt-br/assuntos/regulados/empresas-aereas/Instrucoes-para-a-elaboracao-e-apresentacao-das-demonstracoes-contabeis/microdados/
   # new https://www.gov.br/anac/pt-br/assuntos/regulados/empresas-aereas/Instrucoes-para-a-elaboracao-e-apresentacao-das-demonstracoes-contabeis/microdados/basica2021-01.zip
   if( nchar(month) ==1 ) { month <- paste0('0', month)}
 
-  url_root <- 'https://www.gov.br/anac/pt-br/assuntos/regulados/empresas-aereas/Instrucoes-para-a-elaboracao-e-apresentacao-das-demonstracoes-contabeis/microdados/'
-  file_name <- paste0(type, year, '-', month, '.zip')
+  url_root <- 'https://www.gov.br/anac/pt-br/assuntos/regulados/empresas-aereas/Instrucoes-para-a-elaboracao-e-apresentacao-das-demonstracoes-contabeis/envio-de-informacoes'
+
+  file_name <- paste0('/', type,'/', year, '/',type, year, '-', month, '.zip')
   file_url <- paste0(url_root, file_name)
   return(file_url)
 } # nocov end
 
 
-
-
 #' Put together the url of airfare data files
 #'
 #' @param dom Logical. Defaults to `TRUE` download airfares of domestic
@@ -500,9 +500,9 @@ latlon_to_numeric <- function(df){ # nocov start
   defaultW <- getOption("warn")
   options(warn = -1)
 
-  # fix string
-  df[, latitude := gsub("[\u00c2]", "", latitude) ]
-  df[, longitude := gsub("[\u00c2]", "", longitude) ]
+  # # fix string
+  # df[, latitude := gsub("[\u00c2]", "", latitude) ]
+  # df[, longitude := gsub("[\u00c2]", "", longitude) ]
 
   # convert to numeric
   df[, latitude := parzer::parse_lat(latitude) ]
